@@ -10,11 +10,11 @@ class TestAppend(unittest.TestCase):
         t = SvPkg([SvSequence([SvObj(0, 1.0), SvObj(100, 2.0)]),
                    SvSequence([SvObj(100, 3.0), SvObj(200, 4.0)]),
                    SvSequence([SvObj(150, 5.0), SvObj(300, 6.0)])])\
-            .combine(combineMethod=SvPkg.CombineMethod.DROP_BY_POINT, combineMethodWindow=1)
+            .combine(combine_method=SvPkg.CombineMethod.DROP_BY_POINT, combine_method_window=1)
 
         self.assertEqual(len(t), 5)
 
-        t.appendInit([(0, 1.0), SvObj(100, 2.0), (1000, 2.0, True), 1000])
+        t.append_init([(0, 1.0), SvObj(100, 2.0), (1000, 2.0, True), 1000])
 
         self.assertEqual(len(t), 9)
 
